layers::prelude

Struct Layer

#[repr(C)]
pub struct Layer { pub engine: Arc<Engine>, pub id: NodeRef, pub layout_id: NodeId, /* private fields */ }

Fields

engine: Arc<Engine>id: NodeReflayout_id: NodeId

Implementations

Source

impl Layer

pub fn id(&self) -> NodeRef

pub fn set_key(&self, key: impl Into<String>)

pub fn key(&self) -> String

pub fn set_hidden(&self, hidden: bool)

pub fn hidden(&self) -> bool

pub fn set_pointer_events(&self, pointer_events: bool)

pub fn pointer_events(&self) -> bool

pub fn set_position( &self, value: impl Into<Point>, transition: impl Into<Option<Transition>>, ) -> TransactionRef

pub fn position(&self) -> Point

pub fn position_value_id(&self) -> usize

pub fn change_position(&self, value: impl Into<Point>) -> AnimatedNodeChange

pub fn set_scale( &self, value: impl Into<Point>, transition: impl Into<Option<Transition>>, ) -> TransactionRef

pub fn scale(&self) -> Point

pub fn scale_value_id(&self) -> usize

pub fn change_scale(&self, value: impl Into<Point>) -> AnimatedNodeChange

pub fn set_rotation( &self, value: impl Into<Point3d>, transition: impl Into<Option<Transition>>, ) -> TransactionRef

pub fn rotation(&self) -> Point3d

pub fn rotation_value_id(&self) -> usize

pub fn change_rotation(&self, value: impl Into<Point3d>) -> AnimatedNodeChange

pub fn set_anchor_point( &self, value: impl Into<Point>, transition: impl Into<Option<Transition>>, ) -> TransactionRef

pub fn anchor_point(&self) -> Point

pub fn anchor_point_value_id(&self) -> usize

pub fn change_anchor_point(&self, value: impl Into<Point>) -> AnimatedNodeChange

pub fn set_opacity( &self, value: impl Into<f32>, transition: impl Into<Option<Transition>>, ) -> TransactionRef

pub fn opacity(&self) -> f32

pub fn opacity_value_id(&self) -> usize

pub fn change_opacity(&self, value: impl Into<f32>) -> AnimatedNodeChange

pub fn set_background_color( &self, value: impl Into<PaintColor>, transition: impl Into<Option<Transition>>, ) -> TransactionRef

pub fn background_color(&self) -> PaintColor

pub fn background_color_value_id(&self) -> usize

pub fn change_background_color( &self, value: impl Into<PaintColor>, ) -> AnimatedNodeChange

pub fn set_border_corner_radius( &self, value: impl Into<BorderRadius>, transition: impl Into<Option<Transition>>, ) -> TransactionRef

pub fn border_corner_radius(&self) -> BorderRadius

pub fn border_corner_radius_value_id(&self) -> usize

pub fn change_border_corner_radius( &self, value: impl Into<BorderRadius>, ) -> AnimatedNodeChange

pub fn set_border_color( &self, value: impl Into<PaintColor>, transition: impl Into<Option<Transition>>, ) -> TransactionRef

pub fn border_color(&self) -> PaintColor

pub fn border_color_value_id(&self) -> usize

pub fn change_border_color( &self, value: impl Into<PaintColor>, ) -> AnimatedNodeChange

pub fn set_border_width( &self, value: impl Into<f32>, transition: impl Into<Option<Transition>>, ) -> TransactionRef

pub fn border_width(&self) -> f32

pub fn border_width_value_id(&self) -> usize

pub fn change_border_width(&self, value: impl Into<f32>) -> AnimatedNodeChange

pub fn set_shadow_offset( &self, value: impl Into<Point>, transition: impl Into<Option<Transition>>, ) -> TransactionRef

pub fn shadow_offset(&self) -> Point

pub fn shadow_offset_value_id(&self) -> usize

pub fn change_shadow_offset( &self, value: impl Into<Point>, ) -> AnimatedNodeChange

pub fn set_shadow_radius( &self, value: impl Into<f32>, transition: impl Into<Option<Transition>>, ) -> TransactionRef

pub fn shadow_radius(&self) -> f32

pub fn shadow_radius_value_id(&self) -> usize

pub fn change_shadow_radius(&self, value: impl Into<f32>) -> AnimatedNodeChange

pub fn set_shadow_spread( &self, value: impl Into<f32>, transition: impl Into<Option<Transition>>, ) -> TransactionRef

pub fn shadow_spread(&self) -> f32

pub fn shadow_spread_value_id(&self) -> usize

pub fn change_shadow_spread(&self, value: impl Into<f32>) -> AnimatedNodeChange

pub fn set_shadow_color( &self, value: impl Into<Color>, transition: impl Into<Option<Transition>>, ) -> TransactionRef

pub fn shadow_color(&self) -> Color

pub fn shadow_color_value_id(&self) -> usize

pub fn change_shadow_color(&self, value: impl Into<Color>) -> AnimatedNodeChange

pub fn set_image_filter_progress( &self, value: impl Into<f32>, transition: impl Into<Option<Transition>>, ) -> TransactionRef

pub fn image_filter_progress(&self) -> f32

pub fn image_filter_progress_value_id(&self) -> usize

pub fn change_image_filter_progress( &self, value: impl Into<f32>, ) -> AnimatedNodeChange

pub fn set_clip_content( &self, value: impl Into<bool>, transition: impl Into<Option<Transition>>, ) -> TransactionRef

pub fn clip_content(&self) -> bool

pub fn clip_content_value_id(&self) -> usize

pub fn change_clip_content(&self, value: impl Into<bool>) -> AnimatedNodeChange

pub fn set_clip_children( &self, value: impl Into<bool>, transition: impl Into<Option<Transition>>, ) -> TransactionRef

pub fn clip_children(&self) -> bool

pub fn clip_children_value_id(&self) -> usize

pub fn change_clip_children(&self, value: impl Into<bool>) -> AnimatedNodeChange

pub fn shape(&self, shape: Shape)

Set a custom shape for this layer.

The shape affects the layer’s visual boundary for rendering, hit-testing, and clipping. By default, layers use Shape::RoundRect with the border_corner_radius attribute.

Examples
use layers::prelude::*;

// Create a triangle path
let mut path = skia_safe::Path::new();
path.move_to((50.0, 0.0));
path.line_to((100.0, 100.0));
path.line_to((0.0, 100.0));
path.close();

layer.shape(Shape::from_path(&path));
pub fn set_anchor_point_preserving_position( &self, anchor_point: impl Into<Point>, ) -> Point

Sets the anchor point while compensating the position so the layer stays in the same place on screen. Returns the newly applied position.

pub fn change_size(&self, value: Size) -> AnimatedNodeChange

pub fn set_size( &self, value: impl Into<Size>, transition: impl Into<Option<Transition>>, ) -> TransactionRef

pub fn size(&self) -> Size

pub fn get_node_layout_style(&self) -> Style

pub fn set_layout_style(&self, style: Style)

pub fn set_node_layout_size(&self, size: Size)

pub fn node_layout_style(&self) -> Style

pub fn set_draw_content<F: Into<ContentDrawFunction>>(&self, content_handler: F)

pub fn remove_draw_content(&self)

pub fn add_sublayer<'a>( &self, layer: impl Into<&'a NodeRef>, ) -> Result<(), LayerError>

pub fn prepend_sublayer(&self, layer: Layer) -> Result<(), LayerError>

pub fn set_blend_mode(&self, blend_mode: BlendMode)

pub fn set_display(&self, display: Display)

pub fn add_on_pointer_move<F: Into<PointerHandlerFunction>>( &self, handler: F, ) -> usize

pub fn remove_on_pointer_move(&self, handler_id: usize)

pub fn add_on_pointer_in<F: Into<PointerHandlerFunction>>( &self, handler: F, ) -> usize

pub fn remove_on_pointer_in(&self, handler_id: Option<usize>)

pub fn add_on_pointer_out<F: Into<PointerHandlerFunction>>( &self, handler: F, ) -> usize

pub fn remove_on_pointer_out(&self, handler_id: Option<usize>)

pub fn add_on_pointer_press<F: Into<PointerHandlerFunction>>( &self, handler: F, ) -> usize

pub fn remove_on_pointer_press(&self, handler_id: Option<usize>)

pub fn add_on_pointer_release<F: Into<PointerHandlerFunction>>( &self, handler: F, ) -> usize

pub fn remove_on_pointer_release(&self, handler_id: Option<usize>)

pub fn remove_all_pointer_handlers(&self)

pub fn render_layer(&self) -> RenderLayer

pub fn render_position(&self) -> Point

pub fn render_size_transformed(&self) -> Point

pub fn render_size(&self) -> Point

pub fn render_bounds_transformed(&self) -> Rect

pub fn render_bounds_with_children_transformed(&self) -> Rect

pub fn render_bounds_with_children(&self) -> Rect

pub fn cointains_point(&self, point: impl Into<Point>) -> bool

pub fn children_nodes(&self) -> Vec<NodeRef>

pub fn children(&self) -> Vec<Layer>

pub fn set_image_filter(&self, filter: impl Into<Option<ImageFilter>>)

Sets the image filter for this layer.

pub fn image_filter(&self) -> Option<ImageFilter>

Returns the current image filter.

pub fn image_filter_value_id(&self) -> usize

Returns the value ID for the image filter attribute.

pub fn set_color_filter(&self, filter: impl Into<Option<ColorFilter>>)

Sets the color filter for this layer.

pub fn color_filter(&self) -> Option<ColorFilter>

Returns the current color filter.

pub fn color_filter_value_id(&self) -> usize

Returns the value ID for the color filter attribute.

pub fn set_filter_bounds(&self, bounds: impl Into<Option<Rect>>)

pub fn remove(&self)

pub fn set_effect(&self, effect: impl Effect + 'static)

pub fn remove_effect(&self)

pub fn clear_on_change_size_handlers(&self)

pub fn on_change_size<F: Into<TransactionCallback>>(&self, f: F, once: bool)

pub fn set_image_cached(&self, image_cached: bool)

pub fn set_content_opaque(&self, content_opaque: bool)

Declare that the custom draw content fills the entire layer bounds with opaque pixels. This allows occlusion culling to treat the layer as an occluder even when its background color is transparent.

pub fn set_picture_cached(&self, picture_cache: bool)

pub fn add_follower_node(&self, follower: impl Into<NodeRef>)

pub fn remove_follower_node(&self, follower: impl Into<NodeRef>)

pub fn as_content(&self) -> ContentDrawFunction

pub fn redraw(&self)