NodeBuilder

Struct NodeBuilder 

pub struct NodeBuilder<R: Ratchet = StackedRatchet, T: PlatformOps = DefaultTransport> { /* private fields */ }
Used to construct a running client/peer or server instance

Implementations

Source

impl<R: Ratchet + ContextRequirements, T: PlatformOps> NodeBuilder<R, T>

pub fn build<'a, 'b: 'a, K: NetKernel<R> + 'b>( &'a mut self, kernel: K, ) -> Result<NodeFuture<'b, K>>

Returns a future that represents the both the protocol and kernel execution

pub fn with_node_type(&mut self, node_type: NodeType) -> &mut Self

Defines the node type. By default, Peer is used. If a server is desired, a bind address is expected

use citadel_sdk::prelude::DefaultNodeBuilder;
use citadel_proto::prelude::NodeType;

DefaultNodeBuilder::default().with_node_type(NodeType::server("0.0.0.0:25021").unwrap());
pub fn with_backend(&mut self, backend_type: BackendType) -> &mut Self

Sets the backend used to synchronize client account information. By default, uses the filesystem. When the enterprise feature is set, a SQL database (MySQL, PostgreSQL, SQLite) is available. Using a single SQL cluster can be used in combination with a cluster of load-balancing running [‘NetKernel’]’s on different IPs to construct scaled applications

pub fn with_kernel_executor_settings( &mut self, kernel_executor_settings: KernelExecutorSettings, ) -> &mut Self

Sets the desired settings for the KernelExecutor

pub fn with_server_argon_settings( &mut self, settings: ArgonDefaultServerSettings, ) -> &mut Self

Attaches custom Argon settings for password hashing at the server

pub fn with_server_misc_settings( &mut self, misc_settings: ServerMiscSettings, ) -> &mut Self

Attaches miscellaneous server settings (e.g., transient mode, credential requirements)

pub fn with_underlying_protocol(&mut self, proto: ServerMode<T>) -> &mut Self

Sets the underlying protocol / server configuration for the transport. Default: TLS transport w/ self-signed cert (for NativeIO)

pub fn with_client_config(&mut self, config: T::ClientConfig) -> &mut Self

Sets the client-side transport configuration.

pub fn with_stun_servers<V: Into<String>, S: Into<Vec<V>>>( &mut self, servers: S, ) -> &mut Self

Specifies custom STUN servers. If left unspecified, will use the defaults (twilio and Google STUN servers)

pub fn with_turn_servers<S: Into<Vec<TurnServerConfig>>>( &mut self, servers: S, ) -> &mut Self

Specifies TURN servers for relay-based NAT traversal.

TURN servers relay traffic when direct peer-to-peer connections fail due to restrictive NAT configurations. On WASM targets, these are passed as ICE servers to the WebRTC peer connection.

pub fn with_websocket_listener(&mut self, addr: SocketAddr) -> &mut Self

Adds an optional WebSocket listener to a server node.

When set, the server will accept both its primary transport (TCP/TLS/QUIC) AND WebSocket connections on the specified address. This enables browser clients (via WASM) to connect to the same server.

Has no effect on client/peer nodes.

pub fn with_server_password<V: Into<PreSharedKey>>( &mut self, password: V, ) -> &mut Self

Sets the pre-shared key for the server. Only a server should set this value If no value is set, any client can connect to the server. If a pre-shared key is specified, the client must have the matching pre-shared key in order to register and connect with the server.

pub fn with_server_declared_header_obfuscation<V: Into<HeaderObfuscatorSettings>>( &mut self, header_obfuscator_settings: V, ) -> &mut Self

Sets the header obfuscator settings for the server

Source

impl<R: Ratchet + ContextRequirements> NodeBuilder<R, NativeIO>

NativeIO-specific builder methods for TLS certificate configuration

pub async fn with_native_certs(&mut self) -> Result<&mut Self>

Loads the accepted cert chain stored by the local operating system If a custom set of certs is required, run Self::with_custom_certs This is the default if no client TLS config is specified

pub fn with_insecure_skip_cert_verification(&mut self) -> &mut Self

The client will skip unconditionally server certificate verification This is not recommended

pub async fn with_require_cert_verification(&mut self) -> Result<&mut Self>

Requires server certificate verification, refusing to fall back to the accept-any-cert path even if the peer advertises a self-signed server (i.e. an attacker cannot downgrade the transport by flipping the is_self_signed/domain signal). If no client TLS config has been set yet, the OS-native cert roots are loaded first. Order-independent with respect to the with_*_certs methods.

pub fn with_custom_certs<V: AsRef<[u8]>>( &mut self, custom_certs: &[V], ) -> Result<&mut Self>

Loads a custom list of certs into the acceptable certificate list. Connections that present server certificates that are outside of this list during the handshake process are refused

pub async fn with_pem_file<P: AsRef<Path>>( &mut self, path: P, ) -> Result<&mut Self>

The file should be a PEM formatted certificate